
.. blogpost::
    :title: A couple of interesting modules for IOT
    :keywords: IOT
    :date: 2017-07-17
    :categories: module

    Quoting the documentation from the websites.

    `thingflow-python <https://github.com/mpi-sws-rse/thingflow-python>`_:
    ThingFlow is a (Python3) framework for building IoT event processing dataflows.
    The goal of this framework is to support the creation of robust IoT systems
    from reusable components. These systems must account for noisy/missing
    sensor data, distributed computation, and the need for local (near the
    data source) processing.

    `tsl2591 <https://github.com/maxlklaxl/python-tsl2591>`_:
    This is a simple python library for the Adafruit TSL2591 breakout board based on
    the `Arduino library <https://github.com/adafruit/Adafruit_TSL2591_Library>`_
    from Adafruit. It was developed to work on a Raspberry PI.

    `micropython <https://github.com/micropython/micropython>`_:
    his is the MicroPython project, which aims to put an implementation of
    Python 3.x on microcontrollers and small embedded systems. You can
    find the official website at
    `micropython.org <http://www.micropython.org/>`_.

    `micropython-lib <https://github.com/micropython/micropython-lib>`_:
    micropython-lib is a project to develop a non-monolothic
    standard library for MicroPython.

    `pywifi <https://github.com/awkman/pywifi>`_:
    pywifi provides a cross-platform Python module for manipulating wireless interfaces.

    `python-wifi <https://pypi.python.org/pypi/python-wifi>`_: last update 2015.

    `wifi <https://wifi.readthedocs.io/en/latest/>`_: wifi.
